==> storebounty_account-0.0.1.tar.gz: lib/widget/favcards/fullcard.dart <==
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:storebounty_account/storebounty_account.dart';
import 'package:storebounty_account/widget/constants/constant.dart';
import 'package:storebounty_account/widget/styles/colors.dart';
import 'package:storebounty_account/widget/styles/textstles.dart';

class FullCard extends StatelessWidget {
  final VoidCallback? onClick;
  final String? title;
  final String? description;
  final String? amount;
  final String? image;
  final bool? isFavourite;
  final VoidCallback? removeFavFunc;
  final Color? defaultColor;
  const FullCard({
    Key? key,
    this.onClick,
    this.title,
    this.description,
    this.amount,
    this.image,
    this.isFavourite,
    this.removeFavFunc,
    this.defaultColor,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: onClick,
      child: Container(
        decoration: BoxDecoration(
            color: defaultColor!.withOpacity(0.1),
            borderRadius: BorderRadius.circular(10)),
        child: Row(children: [
          Container(
            margin: EdgeInsets.symmetric(vertical: 16, horizontal: 16),
            height: 80,
            width: 80,
            decoration: BoxDecoration(
                color: AppColors.black.withOpacity(0.2),
                borderRadius: BorderRadius.circular(5),),
            child: image != null ? CachedNetworkImage(
              height: 80,
              width: 80,
              imageUrl: "${image}",
              placeholder: (context, url) =>
                  const Center(child: CircularProgressIndicator()),
              errorWidget: (context, url, error) => Center(
                  child: SvgPicture.asset(
                "assets/icons/defaultimg.svg",
                package: "storebounty_themes",
                height: 100,
                width: 100,
              )),
              fit: BoxFit.cover,
            ):SvgPicture.asset(
                "assets/icons/defaultimg.svg",
                package: "storebounty_themes",
                height: 100,
                width: 100,
              ),
          ),
          Expanded(
              child: Container(
            child: Column(
              mainAxisAlignment: MainAxisAlignment.start,
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Row(
                  children: [
                    Expanded(
                        child: Text(
                      "${title ?? "-"}",
                      style: Styles.p0(),
                    )),
                    InkWell(
                      onTap: removeFavFunc,
                      child: SvgPicture.asset(
                        isFavourite == true
                            ? "$kIconsPath/fav_solid_icon.svg"
                            : "$kIconsPath/fav_icon.svg",
                        color: isFavourite == true
                            ? defaultColor
                            : defaultColor!.withOpacity(0.5),
                      ),
                    ),
                    SizedBox(
                      width: 10,
                    )
                  ],
                ),
                SizedBox(
                  height: 4,
                ),
                Container(
                  child: Row(
                    children: [
                      Expanded(
                        child: Text("${StoreBountyAccount.stripHtml(description) ?? "-"}",
                            maxLines: 2,
                            style: Styles.p3(fontSize: 14, color: Color(0xff7E7E7E))),
                      ),
                      SizedBox(width: 10,)
                    ],
                  ),
                ),
                SizedBox(
                  height: 4,
                ),
                Text("${amount ?? "-"}",
                    style: Styles.p3(fontSize: 14, fontWeight: FontWeight.w600))
              ],
            ),
          ))
        ]),
      ),
    );
  }
}

==> storebounty_account-0.0.5.tar.gz: lib/widget/favcards/fullcard.dart <==
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:storebounty_account/storebounty_account.dart';
import 'package:storebounty_account/widget/constants/constant.dart';
import 'package:storebounty_account/common/styles/colors.dart';
import 'package:storebounty_account/common/styles/textstles.dart';

class FullCard extends StatelessWidget {
  final VoidCallback? onClick;
  final String? title;
  final String? description;
  final String? amount;
  final String? image;
  final bool? isFavourite;
  final VoidCallback? removeFavFunc;
  final Color? defaultColor;
  const FullCard({
    Key? key,
    this.onClick,
    this.title,
    this.description,
    this.amount,
    this.image,
    this.isFavourite,
    this.removeFavFunc,
    this.defaultColor,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: onClick,
      child: Container(
        decoration: BoxDecoration(
            color: defaultColor!.withOpacity(0.1),
            borderRadius: BorderRadius.circular(10)),
        child: Row(children: [
          Container(
            margin: EdgeInsets.symmetric(vertical: 16, horizontal: 16),
            height: 80,
            width: 80,
            decoration: BoxDecoration(
                color: AppColors.black.withOpacity(0.2),
                borderRadius: BorderRadius.circular(5),),
            child: image != null ? CachedNetworkImage(
              height: 80,
              width: 80,
              imageUrl: "${image}",
              placeholder: (context, url) =>
                  const Center(child: CircularProgressIndicator()),
              errorWidget: (context, url, error) => Center(
                  child: SvgPicture.asset(
                "assets/icons/defaultimg.svg",
                package: "storebounty_themes",
                height: 100,
                width: 100,
              )),
              fit: BoxFit.cover,
            ):SvgPicture.asset(
                "assets/icons/defaultimg.svg",
                package: "storebounty_themes",
                height: 100,
                width: 100,
              ),
          ),
          Expanded(
              child: Container(
            child: Column(
              mainAxisAlignment: MainAxisAlignment.start,
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                Row(
                  children: [
                    Expanded(
                        child: Text(
                      "${title ?? "-"}",
                      style: Styles.p0(),
                    )),
                    InkWell(
                      onTap: removeFavFunc,
                      child: SvgPicture.asset(
                        isFavourite == true
                            ? "$kIconsPath/fav_solid_icon.svg"
                            : "$kIconsPath/fav_icon.svg",
                        color: isFavourite == true
                            ? defaultColor
                            : defaultColor!.withOpacity(0.5),
                      ),
                    ),
                    SizedBox(
                      width: 10,
                    )
                  ],
                ),
                SizedBox(
                  height: 4,
                ),
                Container(
                  child: Row(
                    children: [
                      Expanded(
                        child: Text("${StoreBountyAccount.stripHtml(description) ?? "-"}",
                            maxLines: 2,
                            style: Styles.p3(fontSize: 14, color: Color(0xff7E7E7E))),
                      ),
                      SizedBox(width: 10,)
                    ],
                  ),
                ),
                SizedBox(
                  height: 4,
                ),
                Text("${amount ?? "-"}",
                    style: Styles.p3(fontSize: 14, fontWeight: FontWeight.w600))
              ],
            ),
          ))
        ]),
      ),
    );
  }
}
